@@ -12,14 +12,14 @@ def convert_date(dt, now=True):
         return
 
     if isinstance(dt, datetime.datetime):       #datetime类型数据进行数据转换成固定格式
-        return dt.date().strftime("%Y%m%d")
+        return dt.date().strftime("%Y-%m-%d")
 
     if isinstance(dt, datetime.date):          #datetime.date数据类型转换为固定格式
-        return dt.strftime("%Y%m%d")
+        return dt.strftime("%Y-%m-%d")
 
     if isinstance(dt, str):
         from dateutil.parser import parse
-        return parse(dt).date().strftime("%Y%m%d")    #用parse进行格式转换，变成数据类型
+        return parse(dt).date().strftime("%Y-%m-%d")    #用parse进行格式转换，变成数据类型
 
     if hasattr(dt, "to_pydatetime"):                  #判断一个对象里面是否有"to_pydatetime"属性或者"to_pydatetime"方法
         return dt.to_pydatetime().date().strftime("%Y%m%d")
